import { Status } from "../../DataFrame";
import { IDevice } from "../Devices/IDevice";
import { ResponseResult } from "../FieldChangeResult";
import { ICustomUpdateActions } from "./CustomUpdateActions/ICustomUpdateActions";
import { ControllerUpdatesInfo, ControllerUpdateType, ControllerVersion, IDeviceUpdateInfo } from "./IUpdateInfo";
import { Update } from "./IUpdatesProvider";
import { IUpdatesService, UpdateAction, UpdateErrorCode, UpdateProgress } from "./IUpdatesService";
export declare class UpdatesService implements IUpdatesService {
    static readonly ServiceName: string;
    private _updateProviders;
    private _controllerUpdates;
    private _logger;
    private _connection;
    private _appStateService;
    private _extensionService;
    private _updateRequestTimeout;
    constructor();
    GetServiceName(): string;
    CheckDeviceVersionAsync(deviceGuid: string): Promise<string | ResponseResult<UpdateErrorCode>>;
    CheckDeviceVersionAsync(device: IDevice): Promise<string | ResponseResult<UpdateErrorCode>>;
    CheckDeviceUpdateAsync(deviceGuid: string): Promise<IDeviceUpdateInfo | ResponseResult<UpdateErrorCode>>;
    CheckDeviceUpdateAsync(device: IDevice): Promise<IDeviceUpdateInfo | ResponseResult<UpdateErrorCode>>;
    InstallDeviceUpdateAsync<T extends ICustomUpdateActions>(device: IDevice, updateProgress: UpdateProgress, updateAction?: UpdateAction<T> | undefined): Promise<ResponseResult<UpdateErrorCode> | Status.OK>;
    InstallDeviceUpdateAsync<T extends ICustomUpdateActions>(dev: string, updateProgress: UpdateProgress, updateAction?: UpdateAction<T> | undefined): Promise<ResponseResult<UpdateErrorCode> | Status.OK>;
    CheckControllerUpdatesAsync(): Promise<ControllerUpdatesInfo>;
    CheckControllerVersionAsync(): Promise<ControllerVersion[] | ResponseResult<UpdateErrorCode>>;
    InstallControllerUpdateAsync<T extends ICustomUpdateActions>(updateGuid: string, updateProgress: UpdateProgress, updateAction?: UpdateAction<T> | undefined): Promise<Status.OK | ResponseResult<UpdateErrorCode>>;
    InstallControllerUpdateAsync<T extends ICustomUpdateActions>(updateProgress: UpdateProgress, updateAction?: UpdateAction<T> | undefined): Promise<Status.OK | ResponseResult<UpdateErrorCode>>;
    protected UpdateControllerAsync(update: Update, updateProgress: UpdateProgress): Promise<ResponseResult<UpdateErrorCode> | Status.OK>;
}
export declare class ControllerUpdateNotAvailableInfo {
    UpdatedResourceName: string;
    CurrentResourceVersion: string;
    UpdateType: ControllerUpdateType | null;
    ResponseResult: ResponseResult<UpdateErrorCode> | null;
}
